/*
 * Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
 * license agreements.  See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership.  Crate licenses
 * this file to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 * However, if you have executed another commercial license agreement
 * with Crate these terms will supersede the license and you may use the
 * software solely pursuant to the terms of the relevant commercial agreement.
 */

package io.crate.operation.reference.sys.job;

import javax.annotation.Nullable;
import java.util.UUID;

public class JobContextLog {

    private final JobContext jobContext;

    @Nullable
    private final String errorMessage;

    private final long ended;

    public JobContextLog(JobContext jobContext, @Nullable String errorMessage) {
        this.jobContext = jobContext;
        this.errorMessage = errorMessage;
        this.ended = System.currentTimeMillis();
    }

    public UUID id() {
        return jobContext.id;
    }

    public String statement() {
        return jobContext.stmt;
    }

    public long started() {
        return jobContext.started;
    }

    public long ended() {
        return ended;
    }

    @Nullable
    public String errorMessage() {
        return errorMessage;
    }
}
